# onemodel-gui: a graphical user interface for OneModel

[![GitHub Actions][github-actions-badge]](https://github.com/sb2cl/onemodel-gui/actions)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

[github-actions-badge]: https://github.com/sb2cl/onemodel-gui/workflows/python/badge.svg

## Description

`onemodel-gui` is a graphical user interface for OneModel.

## Motivation

OneModel can be used as a Python package or as a command-line interface (`onemodel-cli`), but both options are aimed for expert users with Python programming knowledge. `onemodel-gui` is aimed for non-experts users: it is the best way to start working with OneModel.

## How to setup

`onemodel-gui` can be installed from PyPI and is compatible with Python 3.7+ for Window, Mac and Linux.

The latest package can be installed with:

```sh
pip install onemodel-gui
```

## Quick example

TODO

## Citing

If you use `onemodel-gui` in your research, please use the following citations in your published works:

- Santos-Navarro, F. N., Navarro, J. L., Boada, Y., Vignoni, A., & Picó, J. (2022). "OneModel: an open-source SBML modeling tool focused on accessibility, simplicity, and modularity." *DYCOPS*.

- Santos-Navarro, F. N., Vignoni, A., & Picó, J. (2022). "Multi-scale host-aware modeling for analysis and tuning of synthetic gene circuits for bioproduction." *PhD thesis*.

## License

Copyright 2022 Fernando N. Santos-Navarro, Jose Luis Herrero, Yadira Boada, Alejandro Vignoni, and Jesús Picó

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this software except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
